@@ -8,13 +8,13 @@ use io_uring::{opcode, types};
 use crate::driver::{Action, SharedFd};
 
 #[allow(dead_code)]
-pub struct Send {
+pub(crate) struct Send {
     fd: SharedFd,
     buf: Vec<u8>,
 }
 
 impl Action<Send> {
-    pub fn send(fd: &SharedFd, buf: &[u8]) -> io::Result<Action<Send>> {
+    pub(crate) fn send(fd: &SharedFd, buf: &[u8]) -> io::Result<Action<Send>> {
         let buf = buf.to_vec();
         let entry =
             opcode::Send::new(types::Fd(fd.raw_fd()), buf.as_ptr(), buf.len() as u32).build();
